require 'fwtoolkit/rake/tasks/xcode'
require 'support/project_generator'

describe 'rake build' do

  before(:all) do
    @xcode_workspace = ProjectGenerator::PRJFILE_COMPLETE_CONFIG[:xcode_workspace]
    @xcode_scheme = ProjectGenerator::PRJFILE_COMPLETE_CONFIG[:xcode_scheme]
  end

  before(:each) do
    @project_generator = ProjectGenerator.new
    @project_generator.create_test_project ProjectGenerator::PRJFILE_COMPLETE_CONFIG
    @project_folder = @project_generator.project_folder
    Dir.chdir @project_folder

    @task_mock = double('xcodetask')
    XcodeBuild::Tasks::BuildTask.stub(:new).and_yield(@task_mock)

    # mock configuration common to every test
    @task_mock.should_receive(:invoke_from_within=).with('.').at_least(:once)
    @task_mock.should_receive(:workspace=).with(@xcode_workspace).at_least(:once)
    @task_mock.should_receive(:scheme=).with(@xcode_scheme).at_least(:once)
    @task_mock.should_receive(:formatter=).at_least(:once)
  end

  after(:each) do
    @project_generator.delete_project
  end

  it 'should configure the debug task' do
    @task_mock.should_receive(:configuration=).with('Debug').at_least(:once)
    @task_mock.should_receive(:configuration=).with(any_args()).any_number_of_times
    @task_mock.should_receive(:sdk=).with('iphonesimulator').at_least(:once)
    @task_mock.should_receive(:sdk=).with(any_args()).any_number_of_times

    FWToolkit::Rake::XcodeTask.new
  end

  it 'should configure the testing task' do
    @task_mock.should_receive(:configuration=).with('Debug').at_least(:once)
    @task_mock.should_receive(:configuration=).with(any_args()).any_number_of_times
    @task_mock.should_receive(:sdk=).with('iphoneos').at_least(:once)
    @task_mock.should_receive(:sdk=).with(any_args()).any_number_of_times

    FWToolkit::Rake::XcodeTask.new
  end

  it 'should configure the release task' do
    @task_mock.should_receive(:configuration=).with('Release').at_least(:once)
    @task_mock.should_receive(:configuration=).with(any_args()).any_number_of_times
    @task_mock.should_receive(:sdk=).with('iphoneos').at_least(:once)
    @task_mock.should_receive(:sdk=).with(any_args()).any_number_of_times

    FWToolkit::Rake::XcodeTask.new
  end

  it 'should configure the ci-test task' do
    @task_mock.should_receive(:configuration=).with('Debug').at_least(:once)
    @task_mock.should_receive(:configuration=).with(any_args()).any_number_of_times
    @task_mock.should_receive(:sdk=).with('iphonesimulator').at_least(:once)
    @task_mock.should_receive(:sdk=).with(any_args()).any_number_of_times

    FWToolkit::Rake::XcodeTask.new
  end
end
